<?php
/*
Plugin Name: Prevent Publish Edit
Plugin URI: http://wpmu.org/
Description: Prevents the edit links appearing for published posts, forcing posts to be moved back to draft status before editing
Author: Chris Knowles
Version: 1.0
Author URI: http://wpmu.org
*/

/*
 *  Removes the edit action from the post row actions if the post is published
 */
function pep_post_row_actions( $actions , $post ) {

	if ( $post->post_status == 'publish' ) unset( $actions['edit'] );
		
	return $actions;
}

/*
 *  Blanks the Edit link shown in the public interface if the post is published
 */
function pep_edit_post_link( $link ) {

	global $post;
	
	if ( $post->post_status == 'publish' ) $link = '';
	
	return $link;

}

/*
 *  Removes the Edit Post option from the admin bar if a single post is being shown and
 *  the post is published
 */
function pep_before_admin_bar_render() {

	global $wp_admin_bar, $post;
	
	if ( is_single() && $post->post_status == 'publish' ) $wp_admin_bar->remove_menu('edit');

}

// set up the filters
add_filter( 'post_row_actions' , 'pep_post_row_actions' , 1 , 2 ); 
add_filter( 'edit_post_link' , 'pep_edit_post_link' , 1 );

// set up the action
add_action( 'wp_before_admin_bar_render' , 'pep_before_admin_bar_render' );

?>